# dho_metadata.py

"""
Define metadata for a release of the Digital Heraldry Ontology
"""

from rdflib import URIRef, Literal
from rdflib.namespace import RDF, RDFS, Namespace, OWL, DCTERMS, VANN
from dho_namespaces import *

def add_ontology_metadata(g):
    """
    Define metadata of an ontology release and add it to an rdflib graph `g`.
    """
    g.add((dho_uri, DCTERMS.license, URIRef('https://creativecommons.org/licenses/by/4.0/')))
    g.add((dho_uri, DCTERMS.creator, Literal('Torsten Hiltmann')))
    g.add((dho_uri, DCTERMS.creator, Literal('Philipp Schneider')))
    # dcterms:contributor
    # dcterms:created Creation date
    # owl:priorVersion
    g.add((dho_uri, OWL.versionIRI, URIRef('http://digitalheraldry.org/digital-heraldry-ontology/heraldry/0.1.0')))
    g.add((dho_uri, VANN.preferredNamespacePrefix, Literal('dhoh')))
    g.add((dho_uri, DCTERMS.title, Literal('Digital Heraldry Ontology')))
    g.add((dho_uri, DCTERMS.description, Literal('The Digital Heraldry Ontology enables the encoding of coats of arms, based on the practices of blazoning. This is done by regarding coats of arms as conceptual objects (rather than images or textual representations), composed in a specific way of figures, tinctures, and geometric patterns. In this way, any combination of coats of arms can be created in a machine-readable way. Thereby, the ontology can be used as a controlled vocabulary to annotate and semantically describe coats of arms e.g. on different material objects, which then can be uniquely referenced as Linked Data.', lang='en')))
    #g.add((dho_uri, DCTERMS.description, ))
    # dcterms:bibliographicCitation
    # dcterms:abstract
    # owl:barckwardCompatibilty
    # owl:incompatibleWith
    # dcterms:modified Modification Date
    # dcterms:issued Date of formal publication
    g.add((dho_uri, DCTERMS.publisher, Literal('https://www.geschichte.hu-berlin.de/de/bereiche-und-lehrstuehle/digital-history')))
    # bibo:doi
    # foaf:logo
    # foaf:depiction Diagram for visual documentation