# functions.py

"""
Collection of functions that are needed for multiple mapping tasks
"""

from rdflib import Graph, URIRef, Literal
from dho_namespaces import *

def construct_new_coa_uri(coa_id):
    """
    Constructs a single URI for a new CoatOfArms node in the graph that comlies with the
    ID structure of the project
    """

    if '.0' in coa_id:
        coa_id = coa_id.split('.', 1)[0]

    if '_' in str(coa_id):
        last_id_part = coa_id.split('_', maxsplit=1)[1]
        first_id_part = str(coa_id.split('_', maxsplit=1)[0]).zfill(10)
        complete_id = first_id_part + '_' + last_id_part
    else:
        complete_id = str(coa_id).zfill(10)

    return URIRef(dho_blazon_n + 'CoA' + complete_id)

def serialize_graph(g, output_file_list):
    """
    Serialze an rdflib graph `g` into filenames and formats specified by a list of dictionaries, as defined in `config/`
    """
    for output_option in output_file_list:
        output_rdf_path = output_option['output_file']
        file_format = output_option['file_format']
        g.serialize(destination=output_rdf_path, format=file_format)

        print(f'Created {output_rdf_path}')