# merge_rdf_files_into_kg

"""
Merges multiple rdf files into the Digital Heraldry Knowledge Graph
"""

from rdflib import Graph
import argparse
import json
import functions

if __name__ == '__main__':
    parser = argparse.ArgumentParser(
        description=__doc__,
        formatter_class=argparse.RawDescriptionHelpFormatter
    )

    # parser.add_argument(
    #     'knowledge_graph_file',
    #     type=str,
    #     help='''Name of the file where the Knowledge Graph is stored in. The output is stored in data/rdf-output. If the file already exists, the rdf files to
    #     integrate are integrated into the existing knowledge graph, unless the parameter -d is set'''
    # )
    parser.add_argument(
        '-i',
        '--input-rdf-files',
        nargs='+',
        required=True,
        help='One or multiple rdf files that are to be merged into the knowledge graph, which is set in config-merge_rdf_files_into_kg.json'
    )

    args = parser.parse_args()._get_kwargs()[0][1]

    # Load config file
    with open("config/config-merge_rdf_files_into_kg.json", "r") as config_file:
        mapping_config = json.load(config_file)

    # Initialize rdflib graph object
    g = Graph()

    # Load the existing Knowledge Graph and integrate the new data there, if stated so in the config file
    if mapping_config['existing_ontology'] is not None:
        g.parse(mapping_config['existing_ontology'])

    # Integrate all given rdf graphs into a single one
    for rdf_file in args:
        print(f'Merging {rdf_file} into Knowledge Graph')
        g.parse(rdf_file)

    # Serialize the prepared graph according to options, set in the config file
    functions.serialize_graph(g, mapping_config['output_files'])